@@ -252,7 +252,8 @@ class MotionDetectionSettings(TypedDict):
     timeout: int
 
 
-class ObjectDetectionSettings(TypedDict): ...
+class ObjectDetectionSettings(TypedDict):
+    confidence: float
 
 
 class CameraActivitySettings(TypedDict):
@@ -417,42 +418,42 @@ class Detection(TypedDict):
 
 
 class BaseStateLight(TypedDict):
-    timestamp: str
+    timestamp: int
     lastEvent: NotRequired[Optional["LightStateWithoutLastEvent"]]
 
 
 class BaseStateMotion(TypedDict):
-    timestamp: str
+    timestamp: int
     lastEvent: NotRequired[Optional["MotionStateWithoutLastEvent"]]
 
 
 class BaseStateAudio(TypedDict):
-    timestamp: str
+    timestamp: int
     lastEvent: NotRequired[Optional["AudioStateWithoutLastEvent"]]
 
 
 class BaseStateObject(TypedDict):
-    timestamp: str
+    timestamp: int
     lastEvent: NotRequired[Optional["ObjectStateWithoutLastEvent"]]
 
 
 class BaseStateDoorbell(TypedDict):
-    timestamp: str
+    timestamp: int
     lastEvent: NotRequired[Optional["DoorbellStateWithoutLastEvent"]]
 
 
 class BaseStateSiren(TypedDict):
-    timestamp: str
+    timestamp: int
     lastEvent: NotRequired[Optional["SirenStateWithoutLastEvent"]]
 
 
 class BaseStateBattery(TypedDict):
-    timestamp: str
+    timestamp: int
     lastEvent: NotRequired[Optional["BatteryStateWithoutLastEvent"]]
 
 
 class BaseStateWithoutLastEvent(TypedDict):
-    timestamp: str
+    timestamp: int
 
 
 class MotionSetEvent(TypedDict):
